==> enterprisemodules-wls_config-3.7.1.tar.gz: enterprisemodules-wls_config-3.7.1/lib/puppet/type/shared/wls_config/targettype.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:targettype, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::ArrayProperty

  desc <<-EOD
    An array of target types.

    The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
    When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

        ...{ 'aResource':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

    here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

        wls_cluster{ 'aCluster':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

  EOD

  maps_to('Targets/%{target_name}/Type')


  to_translate_to_resource do | raw_resource, resource|
    wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(raw_resource[:domain])
    targets = resource[:target]
    targets.collect do | target_name|
      my_resource = raw_resource.merge(:target_name => target_name)
      wls_config.get(actual_path(my_resource))
    end
  end

  on_apply do
    # Do nothing, delegate to target
  end

  validate do | value|
    valid_types = ['Server', 'Cluster', 'JMSServer', 'SAFAgent', 'MigratableTarget']
    fail 'You need to specify an Array instead of a comma separated string' if value =~ /,/
    fail "#{value} is invalid as targettype. Valid targettypes are #{valid_types.join(', ')}" unless valid_types.include?(value)
  end
  data_type("Optional[Array[String]]")
end

==> enterprisemodules-wls_config-3.12.2.tar.gz: enterprisemodules-wls_config-3.12.2/lib/puppet/type/shared/wls_config/targettype.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:targettype, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::ArrayProperty

  desc <<-DESC
    An array of target types.

    The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
    When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

        ...{ 'aResource':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

    here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

        wls_cluster{ 'aCluster':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

  DESC

  maps_to('Targets/%<target_name>s/Type')

  to_translate_to_resource do |raw_resource, resource|
    wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(raw_resource[:domain])
    targets = resource[:target]
    targets.collect do |target_name|
      my_resource = raw_resource.merge(:target_name => target_name)
      wls_config.get(actual_path(my_resource))
    end
  end

  on_apply do
    # Do nothing, delegate to target
  end

  validate do |value|
    valid_types = %w[Server Cluster JMSServer SAFAgent MigratableTarget]
    # rubocop:disable Performance/RegexpMatch
    fail 'You need to specify an Array instead of a comma separated string' if value =~ /,/
    # rubocop:enable Performance/RegexpMatch
    fail "#{value} is invalid as targettype. Valid targettypes are #{valid_types.join(', ')}" unless valid_types.include?(value)
  end
  data_type('Optional[Array[String]]')
end
